@@ -69,18 +69,10 @@ class Agent(object):
         if "CAV_APP_AGENT_Env" in os.environ:
             if os.environ['CAV_APP_AGENT_Env'] == "AWS_LAMBDA":
                 self.cav_env = "AWS_LAMBDA"
-            elif os.environ['CAV_APP_AGENT_Env'] == "NATIVE":
+            else:
                 self.cav_env = "NATIVE"
         else:
-            self.cav_env = "AWS_LAMBDA"
-
-        if "CAV_APP_AGENT_Env" in os.environ:
-            if os.environ['CAV_APP_AGENT_Env'] == "AWS_LAMBDA":
-                self.cav_env = "AWS_LAMBDA"
-            elif os.environ['CAV_APP_AGENT_Env'] == "NATIVE":
-                self.cav_env = "NATIVE"
-        else:
-            self.cav_env = "AWS_LAMBDA"
+            self.cav_env = "NATIVE"
 
         if "CAV_APP_AGENT_TIER" in os.environ:
                 self.tier_name = os.environ.get("CAV_APP_AGENT_TIER")
@@ -256,7 +248,7 @@ class Agent(object):
         wsgi.aiflagset(istart, startTime, duration, sname)
         #pathd = "/opt/cavisson/netdiagnostics/logs/"
         nd_home = os.environ.get('ND_HOME')
-        pathd = nd_home + '/logs/'
+        pathd = nd_home + '/python/logs/'
         filenameai1 = str(self.sess.decode('ascii')) + ".txt"
         aifile_to_open_to_d = os.path.join(pathd, filenameai1)
         self.lib.handleUploadDownload(aifile_to_open_to_d)
