@@ -224,7 +224,7 @@ class MethodEntryMessage(object):
                                        self.msg_type,
                                        bytes('|', "utf-8"),
                                        self.mid,
-                                       self.flowpathinstance,
+                                       self.flow_path_instance,
                                        self.threadId,
                                        self.startTime,
                                        self.len_methodName,
@@ -242,7 +242,7 @@ class MethodEntryMessage(object):
 
 class MethodExitMessage(object):
 
-    def __init__(self, methodName, backend_header, status, duration):
+    def __init__(self, methodName, backend_header, status, duration, flow_path_instance):
 
         self.methodName = methodName
         self.backend_header = backend_header
@@ -253,7 +253,7 @@ class MethodExitMessage(object):
         self.eventType = 0  # DUMMY
         self.isCallout = 1  # DUMMY 1
         self.threadId = 0  # DUMMY threading.get_ident()
-        self.flowpathinstance = 0  # DUMMY
+        self.flow_path_instance = flow_path_instance 
         self.cpuTime = 0  # DUMMY
 
         self.len_methodName = None
