@@ -42,16 +42,16 @@ def application_callable_pro(self, application, instance, environ, start_respons
 
             if client_app_root in k[0]:
                 module = k[0]
-                self.agent.logger.info("module:-{}".format(k[0]))
+                print("module:-", k[0])
                 module_path = os.path.split(os.path.abspath(module))[0]
                 modulefullname  = os.path.split(os.path.abspath(module))[1]
                 module_name = modulefullname.split('.')[0]
                 methodname = k[-1]
-                self.agent.logger.info('module path:-{}'.format(module_path))
-                self.agent.logger.info('module name:-{}'.format(module_name))
-                self.agent.logger.info('method name:- {}'.format(k[-1]))
-                self.agent.logger.info('Total call:- {}'.format(v[1]))
-                self.agent.logger.info('Response time of method:-{}'.format(v[3]))
+                print('module path:-', module_path)
+                print('module name:-', module_name)
+                print('method name:- ',k[-1])
+                print('Total call:- ',v[1])
+                print('Response time of method:-',v[3])
                 mod = readmodule(module_name, path=[module_path])
                 li = []
                 for k, v in mod.items():
@@ -69,7 +69,7 @@ def application_callable_pro(self, application, instance, environ, start_respons
                     else:
                         for j in i:
                             if j == methodname:
-                                self.agent.logger.info("classname:-{}".format(li[count-2]))
+                                print("classname:-",li[count-2])
                             else:
                                 pass
     return response
