@@ -14,7 +14,7 @@ havoc_types = {
     4: "OutBoundService_Failure",
     5: "MethodCall_Delay",
     6: "MethodCall_Failure",
-    7: "Custom_Memory_Leak",
+    7: "Custom_Memory_Leak"
 }
 
 
@@ -96,7 +96,7 @@ class NDNetHavocMonitor(object):
                 "OutBoundService_Failure": [],
                 "MethodCall_Delay": [],
                 "MethodCall_Failure": [],
-                "Custom_Memory_Leak": [],
+                "Custom_Memory_Leak": []
             }
 
             self.logger = logging.getLogger('pythonagent.agent')
@@ -240,25 +240,20 @@ class NDNetHavocMonitor(object):
             self.logger.debug("delayInSec not needed")
 
         if havoc_type in [7]:
-            print("HAVOC type 7")
             if not hasattr(havoc_conf, "leaksINMB"):
                 return_message = "leaksINMB not found for custom_memory_leak"
                 return is_valid, return_message
             else:
-                print("leaksINMB", havoc_conf.leaksINMB)
                 if not hasattr(havoc_conf, "memoryLeaksInSec"):
                     return_message = "memoryLeaksInSec not found for custom_memory_leak"
                     return is_valid, return_message
                 else:
-                    print("memoryLeaksInSec", havoc_conf.memoryLeaksInSec)
                     self.logger.debug("memoryLeaksInSec validated")
         else:
             self.logger.debug("leaksINMB, memoryLeaksInSec not needed")
 
         is_valid = True
         return_message = "Config Validated"
-        #increase_memory_usage
-
         return is_valid, return_message
 
     def parse_nethavoc_config(self, json_conf, header_dict):
@@ -267,26 +262,19 @@ class NDNetHavocMonitor(object):
         try:
             havoc_conf = json.loads(json_conf, object_hook=lambda d: namedtuple('X', d.keys())(*d.values()))
             havoc_type = havoc_conf.havocType
-            print("havoc_conf in parser", havoc_conf)
             self.logger.info("Havoc type: {}".format(havoc_type))
-            print("havoc type", havoc_type)
             self.logger.debug("header_dict: {}".format(header_dict))
-            print("header_dict", header_dict)
             nhmid = header_dict["NHMID"]
             self.logger.debug("nhmid: {}".format(nhmid))
             self.logger.info("checking if havoc already exists")
 
             havoc_type_full_str = havoc_types[havoc_type]
-            print("havoc_type_full_str", havoc_type_full_str)
-            print("nethavocmap", self.netHavocConfigMap)
             config_list = self.netHavocConfigMap[havoc_type_full_str]
-            print("initial config list", config_list)
             self.logger.info("config_list: {}".format(config_list))
 
             if config_list:
                 for config in config_list:
                     if nhmid == config.nhmid:
-                        print("config in parser", config)
                         self.logger.info("havoc already exists skipping")
                         return
 
@@ -302,6 +290,7 @@ class NDNetHavocMonitor(object):
             else:
                 self.logger.info("Invalid config: {}".format(ret_message))
 
+            
             if havoc_type == 7:
                 self.increase_memory_usage()
             else:
@@ -438,7 +427,6 @@ class NDNetHavocMonitor(object):
     def apply_method_call_delay(self, req_method_fqm):
         self.logger.info("Trying to apply method call delay")
         config_list = self.netHavocConfigMap["MethodCall_Delay"]
-        print("config_list inside havoc mamanger method call delay", config_list)
 
         if config_list:
             for config in config_list:
@@ -474,25 +462,18 @@ class NDNetHavocMonitor(object):
             self.logger.debug("config not set for apply_method_call_failure")
 
     def increase_memory_usage(self):
-        print("Trying to apply memory leak")
         self.logger.info("Trying to apply memory leak")
         config_list = self.netHavocConfigMap["Custom_Memory_Leak"]
-        print("config list", config_list)
         if config_list:
             for config in config_list:
-                print("HERE CONFIG", config)
                 self.logger.debug("Trying to apply havoc: {}".format(config.nhmid))
                 leaksINMB = config.leaksINMB
-                print("HERE")
-                print("leaksinmb", leaksINMB)
                 totalDurationInSec = config.totalDurationInSec
-                print("totalDurationInSec", totalDurationInSec)
                 memoryLeaksInSec = config.memoryLeaksInSec
-                print("memoryLeaksInSec", memoryLeaksInSec)
                 apply_memory_leak(leaksINMB, totalDurationInSec, memoryLeaksInSec)
 
         else:
-            self.logger.error("config not set for apply_method_call_failure")
+            self.logger.debug("config not set for apply_method_call_failure")
 
     def increase_cpu_utilization(self):
         pass
