@@ -22,7 +22,7 @@ class LoggingInterceptor(BaseInterceptor):
                 record.msg = str(record.msg)
 
             context = self.agent.get_transaction_context()
-            recordReqIdmsg = f" [ RequestId : {context.aws_request_id} ] " + record.msg
+            recordReqIdmsg = f" [ RequestId : {context.aws_request_id} ] " + record.msg + f" [flow_path_id : {context.flow_path_id}]"
             record.msg = recordReqIdmsg
         except Exception as e:
             print(e)
