@@ -144,8 +144,9 @@ def command(options, args):
         pythonpath.append(environ['PYTHONPATH'])
 
     environ['PYTHONPATH'] = ':'.join(pythonpath)
-    environ['LD_LIBRARY_PATH'] = "/usr/local/lib"
-    environ['LD_PRELOAD'] = "/usr/local/lib/libapr-1.so /usr/local/lib/libwebsockets.so /usr/local/lib/libcrypto.so /usr/local/lib/libssl.so"
+    #environ['CAV_APP_AGENT_Env']= "NATIVE"
+    #environ['LD_LIBRARY_PATH'] = "/usr/local/lib"
+    environ['LD_PRELOAD'] = "libapr-1.so libwebsockets.so"
     #print('ND_HOME set as ',environ.get('ND_HOME'))
     print("ND_HOME Environment variable :", environ.get('ND_HOME'))
     if environ.get('ND_HOME') is None:
